@@ -3,7 +3,9 @@ import os
 
 from supabase import Client, create_client
 
-from .config import CONFIG_DIR, CONFIG_FILE, SUPABASE_KEY, SUPABASE_URL
+from arcadia.utils.settings import Settings
+
+from .config import CONFIG_DIR, CONFIG_FILE
 
 
 def save_credentials(username: str, api_key: str):
@@ -25,7 +27,8 @@ def load_credentials():
 def validate_credentials(username: str, api_key: str) -> bool:
     """Validate credentials against Supabase"""
     try:
-        supabase: Client = create_client(SUPABASE_URL, SUPABASE_KEY)
+        settings = Settings()
+        supabase: Client = create_client(settings.supabase_url, settings.supabase_key)
         response = (
             supabase.table("users")
             .select("*")
